@@ -22,35 +22,7 @@ VFLOW_PATHS = {'operators':'files/vflow/subengines/com/sap/python36/operators/',
                'pipelines':'files/vflow/graphs/',
                'dockerfiles':'files/vflow/dockerfiles/'}
 
-def save_open(file):
-    parentpath = path.dirname(file)
-    try:
-        makedirs(parentpath)
-    except OSError as exc: # Python >2.5
-        if exc.errno == errno.EEXIST and path.isdir(parentpath):
-            pass
-        else: raise
-    return open(file, 'w')
 
-def download(artifact,artifact_type='operator') :
-
-    apath = VFLOW_PATHS[artifact_type]
-    if artifact == '.' :
-        artifact_path = apath
-    else :
-        artifact_path = path.join(apath,artifact.replace('.','/'))
-    logging.info(f'Download {artifact_type}: {artifact_path}')
-    files = get_all_files(artifact_path)
-
-    for f in files :
-        content = read_file(f)
-        art_path = re.sub(f'^{apath}','',f)
-        art_path = art_path.replace('/',path.sep)
-        rpath =  path.join(getcwd(),artifact_type,art_path)
-
-        with save_open(rpath) as fp :
-            logging.info(f'Save file: {rpath}')
-            fp.write(content)
 
 def change_target_dir(artifact_type,members) :
     for tarinfo in members:
@@ -71,7 +43,7 @@ def main() :
     parser.add_argument('artifact_type', help='Type of artifacts.',choices=achoices)
     parser.add_argument('artifact', help='Artifact name (package, graph or dockerfile)')
     parser.add_argument('-n', '--solution', help='Solution imported to vrep before artifacts downloaded.')
-    parser.add_argument('-v', '--version', help='If artifact is of solution type then version is needed')
+    parser.add_argument('-v', '--version', help='Version of solution. Required for option --solution')
     parser.add_argument('-u', '--user', help='SAP Data Intelligence user if different from login-user. Not applicable for solutions-download')
     parser.add_argument('-g', '--gitcommit', help='Git commit for the downloaded files',action='store_true')
     args = parser.parse_args()
@@ -107,7 +79,12 @@ def main() :
             logging.info(f'Extract \'{target}\' to: {args.artifact_type}')
             tar.extractall(path=args.artifact_type,members=change_target_dir(args.artifact_type,tar))
 
+    if args.gitcommit :
 
+        folder = path.join(args.artifact_type,args.artifact)
+        logging.info(f'Auto-commit of downloaded artifact: {folder}')
+        run(['git','add',folder])
+        run(['git','commit','-m','didownload'])
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
