@@ -9,6 +9,7 @@ import logging
 import argparse
 import tarfile
 import re
+from subprocess import run
 
 import yaml
 
@@ -43,6 +44,7 @@ def main() :
     parser.add_argument('-s', '--description', help='Description string for solution.')
     parser.add_argument('-v', '--version', help='Version of solution. Necessary if exported to solution repository.',default='0.0.1')
     parser.add_argument('-u', '--user', help='SAP Data Intelligence user if different from login-user. Not applicable for solutions-upload')
+    parser.add_argument('-g', '--gitcommit', help='Git commit for the uploaded files',action='store_true')
     args = parser.parse_args()
 
     config_file = 'config.yaml'
@@ -82,5 +84,12 @@ def main() :
         source = path.join(VFLOW_PATHS[args.artifact_type],basename)
         solution_to_repo(source, args.solution, args.version, args.description)
 
+    if args.gitcommit :
+        folder = path.join(args.artifact_type,args.artifact)
+        logging.info(f'Auto-commit for uploaded artifact: {folder}')
+        run(['git','add',folder])
+        run(['git','commit','-m','didownload'])
+
+
 if __name__ == '__main__':
     main()
\ No newline at end of file
